%define major     19
%define libname   %mklibname websockets %{major}
%define develname %mklibname websockets -d

Name:           libwebsockets
Version:        4.3.2
Release:        %mkrel 1
Summary:        A lightweight C library for Websockets
Group:          System/Libraries
# base64-decode.c and ssl-http2.c is under MIT license with FPC exception.
# sha1-hollerbach is under BSD
# https://fedorahosted.org/fpc/ticket/546
# Test suite is licensed as Public domain (CC-zero)
License:        LGPLv2 and Public Domain and BSD and MIT and zlib
URL:            https://libwebsockets.org/
Source0:        https://github.com/warmcat/libwebsockets/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         libwebsockets-4.2.0-fix-build.patch

BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  openssl
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)

Provides:       bundled(sha1-hollerbach)
Provides:       bundled(base64-decode)
Provides:       bundled(ssl-http2)

%description
This is the libwebsockets C library for lightweight websocket clients
and servers.

#------------------------------------------------

%package -n     %{libname}
Summary:        A lightweight C library for Websockets
Group:          System/Libraries

%description -n %{libname}
This is the libwebsockets C library for lightweight websocket clients
and servers.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       websockets-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%package tests
Summary:        Tests to use with %{name}
Group:          System/Libraries

%description tests
This package contains the tests for %{name} applications.

#------------------------------------------------

%prep
%autosetup -p1

%build
%cmake \
    -DLWS_SUPPRESS_DEPRECATED_API_WARNINGS=ON \
    -DLWS_WITH_HTTP2=ON \
    -DLWS_IPV6=ON \
    -DLWS_WITH_ZIP_FOPS=ON \
    -DLWS_WITH_SOCKS5=ON \
    -DLWS_WITH_RANGES=ON \
    -DLWS_WITH_ACME=ON \
    -DLWS_WITH_LIBEV=ON \
    -DLWS_WITH_LIBUV=ON \
    -DLWS_WITH_LIBEVENT=OFF \
    -DLWS_WITH_FTS=ON \
    -DLWS_WITH_THREADPOOL=OFF \
    -DLWS_UNIX_SOCK=ON \
    -DLWS_WITH_HTTP_PROXY=ON \
    -DLWS_WITH_DISKCACHE=ON \
    -DLWS_WITH_LWSAC=ON \
    -DLWS_LINK_TESTAPPS_DYNAMIC=ON \
    -DLWS_WITHOUT_BUILTIN_GETIFADDRS=ON \
    -DLWS_WITH_BUNDLED_ZLIB_DEFAULT=OFF \
    -DLWS_WITHOUT_BUILTIN_SHA1=ON \
    -DLWS_WITH_STATIC=OFF \
    -DLWS_WITHOUT_CLIENT=OFF \
    -DLWS_WITHOUT_SERVER=OFF \
    -DLWS_WITHOUT_TESTAPPS=OFF \
    -DLWS_WITHOUT_TEST_SERVER=OFF \
    -DLWS_WITHOUT_TEST_SERVER_EXTPOLL=OFF \
    -DLWS_WITHOUT_TEST_PING=OFF \
    -DLWS_WITHOUT_TEST_CLIENT=OFF \
    -DLWS_WITHOUT_EXTENSIONS=OFF \
    -DLWS_WITH_SQLITE3=ON \
    -DDISABLE_WERROR=ON \
    -DLIBEV_INCLUDE_DIRS=%{_includedir}/libev

%cmake_build

%install
%cmake_install

find %{buildroot} -name '*_static.pc' -delete

%files -n %{libname}
%doc README.md changelog
%license LICENSE
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc READMEs/README.coding.md READMEs/ changelog
%license LICENSE
%{_includedir}/*.h
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/%{name}-evlib_ev.so
%{_libdir}/%{name}-evlib_uv.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/libwebsockets/

%files tests
%doc READMEs/README.coding.md READMEs/README.test-apps.md
%license LICENSE
%{_bindir}/%{name}-test-*
%{_datadir}/%{name}-test-server/


%changelog
* Tue Sep 13 2022 neoclust <neoclust> 4.3.2-1.mga9
+ Revision: 1887539
- New version  4.3.2

* Mon Mar 21 2022 danf <danf> 4.2.0-3.mga9
+ Revision: 1815029
- Switch to https URL
- Disable deprecation warnings to allow compiling against OpenSSL 3
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ wally <wally>
- rebuild for openssl 3.0.0

* Mon Apr 19 2021 daviddavid <daviddavid> 4.2.0-1.mga9
+ Revision: 1716994
- new version: 4.2.0
- add upstream patch to fix build
  * https://github.com/warmcat/libwebsockets/issues/2278
- now libmajor is 18

* Fri Dec 04 2020 daviddavid <daviddavid> 4.1.6-1.mga8
+ Revision: 1652418
- new version: 4.1.6

* Wed Oct 28 2020 daviddavid <daviddavid> 4.1.4-1.mga8
+ Revision: 1639960
- new version: 4.1.4

* Wed Oct 14 2020 daviddavid <daviddavid> 4.1.3-1.mga8
+ Revision: 1635576
- new version: 4.1.3

* Thu Sep 24 2020 daviddavid <daviddavid> 4.1.2-1.mga8
+ Revision: 1629700
- new version: 4.1.2

* Fri Sep 11 2020 daviddavid <daviddavid> 4.1.0-1.mga8
+ Revision: 1624709
- new version: 4.1.0
- now libmajor is 17

* Wed Jul 15 2020 daviddavid <daviddavid> 4.0.20-1.mga8
+ Revision: 1606384
- new version: 4.0.20

* Wed Jun 24 2020 daviddavid <daviddavid> 4.0.19-1.mga8
+ Revision: 1599014
- new version: 4.0.19

* Mon Jun 15 2020 daviddavid <daviddavid> 4.0.16-1.mga8
+ Revision: 1593352
- new version: 4.0.16

* Mon Jun 08 2020 daviddavid <daviddavid> 4.0.15-1.mga8
+ Revision: 1590976
- new version: 4.0.15

* Tue Jun 02 2020 daviddavid <daviddavid> 4.0.13-1.mga8
+ Revision: 1589629
- new version: 4.0.13

* Tue May 26 2020 daviddavid <daviddavid> 4.0.12-1.mga8
+ Revision: 1587666
- new version: 4.0.12

* Tue May 19 2020 daviddavid <daviddavid> 4.0.10-1.mga8
+ Revision: 1586120
- new version: 4.0.10

* Thu May 14 2020 daviddavid <daviddavid> 4.0.7-1.mga8
+ Revision: 1583613
- new version: 4.0.7

* Mon May 04 2020 daviddavid <daviddavid> 4.0.4-1.mga8
+ Revision: 1578690
- new version: 4.0.4

* Fri May 01 2020 daviddavid <daviddavid> 4.0.2-1.mga8
+ Revision: 1577366
- new version: 4.0.2

* Thu Mar 12 2020 daviddavid <daviddavid> 4.0.1-1.mga8
+ Revision: 1555728
- new version: 4.0.1
- now libmajor is 16

* Wed Feb 19 2020 umeabot <umeabot> 3.2.2-2.mga8
+ Revision: 1543505
- Mageia 8 Mass Rebuild

* Tue Jan 21 2020 daviddavid <daviddavid> 3.2.2-1.mga8
+ Revision: 1481799
- new version: 3.2.2
+ wally <wally>
- build with new cmake macros

* Thu Dec 19 2019 daviddavid <daviddavid> 3.2.1-1.mga8
+ Revision: 1468985
- new version: 3.2.1

* Mon Aug 19 2019 daviddavid <daviddavid> 3.2.0-1.mga8
+ Revision: 1430248
- new version: 3.2.0
- now libmajor is 15

* Sat Nov 24 2018 daviddavid <daviddavid> 3.1.0-1.mga7
+ Revision: 1333893
- new version: 3.1.0
- now libmajor is 14

* Thu Oct 11 2018 daviddavid <daviddavid> 3.0.1-1.mga7
+ Revision: 1319490
- new version: 3.0.1

* Sun Sep 23 2018 umeabot <umeabot> 3.0.0-3.mga7
+ Revision: 1299223
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 daviddavid <daviddavid> 3.0.0-2.mga7
+ Revision: 1242737
- add upstream patch to fix libuv change header location in 1.21.0

* Mon May 21 2018 daviddavid <daviddavid> 3.0.0-1.mga7
+ Revision: 1230992
- initial package libwebsockets

